<?php

namespace Internetgalerie\IgWidgets\Widgets;

use Internetgalerie\IgWidgets\Utility\CookieUtility;
use TYPO3\CMS\Core\Page\PageRenderer;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Dashboard\Widgets\AdditionalCssInterface;
use TYPO3\CMS\Dashboard\Widgets\AdditionalJavaScriptInterface;
use TYPO3\CMS\Dashboard\Widgets\ButtonProviderInterface;
use TYPO3\CMS\Dashboard\Widgets\WidgetConfigurationInterface;
use TYPO3\CMS\Dashboard\Widgets\WidgetInterface;
use TYPO3\CMS\Fluid\View\StandaloneView;

class CookieHelperWidget implements WidgetInterface, AdditionalJavaScriptInterface, AdditionalCssInterface
{
    /**
     * @var WidgetConfigurationInterface
     */
    private $configuration;

    /**
     * @var StandaloneView
     */
    private $view;

    /**
     * @var array
     */
    private $options;

    /**
     * @var array
     */
    private $cookie;

    /**
     * @var ButtonProviderInterface|null
     */
    private $buttonProvider;

    public function __construct(
        WidgetConfigurationInterface $configuration,
        StandaloneView $view,
        ButtonProviderInterface $buttonProvider = null,
        array $options = []
    ) {
        $this->configuration = $configuration;
        $this->view = $view;
        $this->options = $options;
        $this->buttonProvider = $buttonProvider;
        $cookieUtility = GeneralUtility::makeInstance(CookieUtility::class);
        $this->defaultCookies = $cookieUtility->getDefault();
        $this->autoCookies = $cookieUtility->getAuto();
        $this->autoCookiesConf = $cookieUtility->getAutoConf();
        $this->renderWidgetContent();
    }
    public function getJsFiles(): array
    {
        $pageRenderer = GeneralUtility::makeInstance(PageRenderer::class);
        $pageRenderer->loadRequireJsModule('TYPO3/CMS/IgWidgets/daterangepicker');
        $pageRenderer->loadRequireJsModule('TYPO3/CMS/IgWidgets/select2/select2');

        return [
            'EXT:ig_widgets/Resources/Public/JavaScript/CookieHelperWidget.js'
        ];
    }
    public function getCssFiles(): array
    {
        return [
            'EXT:ig_widgets/Resources/Public/Css/daterangepicker.css',
            'EXT:ig_widgets/Resources/Public/Css/CookieHelperWidget.css',
            'EXT:ig_widgets/Resources/Public/Css/select2/select2.min.css',
        ];
    }

    public function renderWidgetContent(): string
    {
        $this->view->setTemplate($this->options['template']);
        $this->view->assignMultiple(
            [
                'options' => $this->options,
                'configuration' => $this->configuration,
                'defaultCookies' => $this->defaultCookies,
                'autoCookies' => $this->autoCookies,
                'autoCookiesConf' => $this->autoCookiesConf,
            ]
        );
        return $this->view->render();
    }
    /**
     * This method returns the options of the widget as set in the registration.
     */
    public function getOptions(): array
    {
        return $this->options;
    }
}
