<?php

namespace Internetgalerie\IgWidgets\Widgets;

use TYPO3\CMS\Backend\Backend\Shortcut\ShortcutRepository;
use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Dashboard\Widgets\AdditionalCssInterface;
use TYPO3\CMS\Dashboard\Widgets\ButtonProviderInterface;
use TYPO3\CMS\Dashboard\Widgets\ListDataProviderInterface;
use TYPO3\CMS\Dashboard\Widgets\RequireJsModuleInterface;
use TYPO3\CMS\Dashboard\Widgets\WidgetConfigurationInterface;
use TYPO3\CMS\Dashboard\Widgets\WidgetInterface;
use TYPO3\CMS\Fluid\View\StandaloneView;

class ShortcutWidget implements WidgetInterface, RequireJsModuleInterface
{
    /**
     * @var WidgetConfigurationInterface
     */
    private $configuration;

    /**
     * @var ShortcutRepository
     */
    protected $shortcutRepository;


    /**
     * @var StandaloneView
     */
    private $view;

    /**
     * @var array
     */
    private $options;

    /**
     * @var ButtonProviderInterface|null
     */
    private $buttonProvider;

    public function __construct(
        WidgetConfigurationInterface $configuration,
        StandaloneView $view,
        ButtonProviderInterface $buttonProvider = null,
        array $options = []
    ) {
        $this->configuration = $configuration;
        $this->view = $view;
        $this->options =  array_merge(
            [
                'template' => 'IgWidgets/Widget/ShortcutWidget',
            ],
            $options
        );
        $this->shortcutRepository = GeneralUtility::makeInstance(ShortcutRepository::class);
        $this->buttonProvider = $buttonProvider;
    }

    public function getRequireJsModules(): array
    {
        return [
            'TYPO3/CMS/Backend/Toolbar/ShortcutMenu',
        ];
    }
    public function renderWidgetContent(): string
    {

        $shortcutMenu = $this->getShortcutMenu();

        $this->view->setTemplate($this->options['template']);
        $this->view->assignMultiple(
            [
            'shortcutMenu' => $shortcutMenu,
            'options' => $this->options,
            //'button' => $this->getButton(),
            'configuration' => $this->configuration,
            ]
        );
        return $this->view->render();
    }
    public function getShortcutMenu()
    {
        $shortcutMenu = [];
        $groups = $this->shortcutRepository->getGroupsFromShortcuts();
        arsort($groups, SORT_NUMERIC);
        
        foreach ($groups as $groupId => $groupLabel) {
            $shortcutMenu[] = [
                'id' => (int)$groupId,
                'title' => $groupLabel,
                'shortcuts' => $this->shortcutRepository->getShortcutsByGroup($groupId),
            ];
        }
        return $shortcutMenu;
    }
    /**
     * This method returns the options of the widget as set in the registration.
     */
    public function getOptions(): array
    {
        return $this->options;
    }

}